@@ -163,7 +163,11 @@ class Module(RedisMixin, LoggingMixin, RollbarMixin):
                 last_document = worker.get(
                     path="/v1/data/corva", collection=self.collection, asset_id=asset_id,
                     sort="{timestamp: -1}", limit=1,
-                ).data[0]
+                ).data
+                if last_document:
+                    last_document = last_document[0]
+                else:
+                    last_document = None
 
         res = self.configure_output_at_config_change(
             main_structure, active_string_type, active_string__id, warning, last_document
