@@ -79,22 +79,41 @@ def none_to_nan(data):
     return data
 
 
-def get_value_from_dict(d: dict, key: str, func):
+def get_value_from_dict(data: dict, key: str, func=lambda x: x, default=None):
     """
     An structured way of getting data from a dict.
-    :param d:
+    :param data:
     :param key:
     :param func: the type of the data (int, str, float, ...)
+    :param default:
     :return:
     """
-    value = d.get(key, None)
+    value = data.get(key, None)
     if value is not None:
         try:
-            return func(value)
+            return_value = func(value)
+            return return_value
         except ValueError:
             pass
 
-    return None
+    return default
+
+
+def get_dict_data_by_path(data: dict, key_path: str, default=None):
+    """
+    To find the path to a key in data dictionary.
+    Note that none of the keys should end up in a list
+    :param data:
+    :param key_path: path to the final key, e.g. 'data.X.Y'
+    :param default:
+    :return:
+    """
+    keys = key_path.split('.')
+    for key in keys:
+        data = data.get(key, {})
+    if not data:
+        return default
+    return data
 
 
 def is_in_and_not_none(d: dict, key: str):
